@@ -21,7 +21,6 @@ def _env(name, fallback=None):
     "--db-host",
     type=str,
     default=_env("DB_HOST"),
-    prompt="Database Hostname",
     show_default=True,
     help="PSQL database hostname",
 )
@@ -29,7 +28,6 @@ def _env(name, fallback=None):
     "--db-port",
     type=int,
     default=_env("DB_PORT", 5432),
-    prompt="Database Port",
     show_default=True,
     help="PSQL database port",
 )
@@ -37,7 +35,6 @@ def _env(name, fallback=None):
     "--db-user",
     type=str,
     default=_env("DB_USER"),
-    prompt="Database Username",
     show_default=True,
     help="PSQL database username",
 )
@@ -45,7 +42,6 @@ def _env(name, fallback=None):
     "--db-password",
     type=str,
     default=_env("DB_PASSWORD"),
-    prompt="Database Password",
     hide_input=True,
     help="PSQL database password",
 )
@@ -53,7 +49,6 @@ def _env(name, fallback=None):
     "--db-schema",
     type=str,
     default=_env("DB_SCHEMA", "public"),
-    prompt="Database Schema",
     show_default=True,
     help="PSQL database schema",
 )
@@ -61,7 +56,6 @@ def _env(name, fallback=None):
     "--db-name",
     type=str,
     default=_env("DB_NAME"),
-    prompt="Database Name",
     show_default=True,
     help="PSQL database name",
 )
@@ -69,7 +63,6 @@ def _env(name, fallback=None):
     "--gcp-project",
     type=str,
     default=_env("GCP_PROJECT"),
-    prompt="GCP Project ID",
     show_default=True,
     help="BigQuery project ID",
 )
@@ -84,7 +77,6 @@ def _env(name, fallback=None):
     "--gcp-credential-path",
     type=str,
     default=_env("GCP_CREDENTIAL_PATH"),
-    prompt="GCP Credentials file location",
     show_default=True,
     help="BigQuery application credentials location",
 )
@@ -131,7 +123,7 @@ def run(
     db_name: str,
     gcp_project: str,
     gcp_dataset: str,
-    gcp_credentials: str,
+    gcp_credential_path: str,
     dump_dir: str,
     delimiter: str,
     quote: str,
@@ -140,7 +132,6 @@ def run(
     exclude_prefix: List[str],
 ):
     """Export PostgreSQL tables as BigQuery tables."""
-
     source = SourceConfig(
         hostname=db_host,
         user=db_user,
@@ -152,7 +143,7 @@ def run(
     target = TargetConfig(
         project=gcp_project,
         dataset=gcp_dataset or db_name,
-        credential_path=Path(gcp_credentials),
+        credential_path=Path(gcp_credential_path),
     )
     dump_config = DumpConfig(
         dump_directory=Path(dump_dir),
@@ -175,8 +166,9 @@ def run(
     for table_name in psql.list_tables():
         logging.info(f"[{table_name}]")
         file_path = psql.dump_table(table_name=table_name)
+        schema = bigquery.build_schema(psql_column_types=psql.get_columns(table_name=table_name))
         try:
-            table_id = bigquery.load_to_bigquery(table_name=table_name, file_path=file_path)
+            table_id = bigquery.load_to_bigquery(table_name=table_name, file_path=file_path, schema=schema)
             logging.info(f"\tPSQL ---> BIGQUERY [{table_name}]: {bigquery.check_table(table_id=table_id)} rows")
             os.remove(file_path)
         except BadRequest as exc:
