@@ -28,9 +28,11 @@ def _setup_sentry():
         )
         sentry_sdk.init(  # pylint: disable=abstract-class-instantiated
             dsn=sentry_dsn,
+            environment=os.environ.get("ENV"),
             integrations=[sentry_logging],
         )
 
 
 def _setup_stout():
     logging.getLogger().addHandler(logging.StreamHandler(sys.stdout))
+    logging.getLogger().setLevel("INFO")
