@@ -16,7 +16,7 @@ class PostgreSQLClient:
 
     _connection: ClassVar = None
 
-    def __postinit__(self):
+    def __post_init__(self):
         if not self._connection:
             self._connection = psycopg2.connect(
                 host=self.source.hostname,
@@ -28,14 +28,14 @@ class PostgreSQLClient:
         return self._connection
 
     def _execute_query(self, sql: str) -> Iterable:
-        cur = self._connection().cursor()
+        cur = self._connection.cursor()
         cur.execute(sql)
         self._connection.commit()
         output = cur.fetchall()
         return output
 
     def dump_table(self, table_name: str) -> Path:
-        cur = self._connection().cursor()
+        cur = self._connection.cursor()
 
         file = self.dump_config.dump_directory / f"{table_name}.csv"
         file.parent.mkdir(exist_ok=True, parents=True)
@@ -56,10 +56,11 @@ class PostgreSQLClient:
     def list_tables(self) -> Generator[str, None, None]:
         def _is_accepted(name):
             cleaned_name = name.lower()
-            return (
-                cleaned_name in self.dump_config.include_tables
-                or cleaned_name not in self.dump_config.skip_tables
-                or any(cleaned_name.startswith(prefix) for prefix in self.dump_config.skip_tables_prefix)
+            if self.dump_config.include_tables:
+                return cleaned_name in self.dump_config.include_tables
+
+            return cleaned_name not in self.dump_config.skip_tables or any(
+                cleaned_name.startswith(prefix) for prefix in self.dump_config.skip_tables_prefix
             )
 
         def _fetch_names(query):
@@ -77,5 +78,17 @@ class PostgreSQLClient:
         sql = f"select table_name from INFORMATION_SCHEMA.views WHERE table_schema='{schema}'"
         yield from _fetch_names(query=sql)
 
+    def get_columns(self, table_name):
+        sql = (
+            "SELECT column_name, data_type FROM information_schema.columns "
+            f"WHERE table_name='{table_name}' "
+            "ORDER BY ordinal_position ASC;"
+        )
+
+        columns = {}
+        for row in self._execute_query(sql=sql):
+            columns[row[0]] = row[1]
+        return columns
+
     def close(self) -> None:
-        self._connection().close()
+        self._connection.close()
